@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 
 #include <QGraphicsScene>
@@ -14,7 +14,7 @@
 #include <math.h>
 
 #include "data_item.h"
-#include "data_control.h"
+#include "sem_mediator.h"
 #include "con.h"
 #include "canvas_item.h"
 #include "canvas_flag.h"
@@ -31,8 +31,9 @@ canvas_flag::canvas_flag(canvas_view *i_oGraphWidget, canvas_item *i_oFrom)
 	/* set the z value to 51 */
 	setZValue(51);
 
-        i_oGraphWidget->scene()->addItem(this);
+	i_oGraphWidget->scene()->addItem(this);
 	setParentItem(m_oItem);
+	setCacheMode(QGraphicsItem::DeviceCoordinateCache);
 }
 
 void canvas_flag::paint(QPainter *i_oPainter, const QStyleOptionGraphicsItem *i_oOption, QWidget * i_oW)
@@ -42,14 +43,14 @@ void canvas_flag::paint(QPainter *i_oPainter, const QStyleOptionGraphicsItem *i_
 	{
 		if (this == m_oItem->m_oFlags[i]) { l_iIndex = i; break; }
 	}
-	data_item *l_oDataItem = m_oGraph->m_oControl->m_oItems.value(m_oItem->Id());
+	data_item *l_oDataItem = m_oGraph->m_oMediator->m_oItems.value(m_oItem->Id());
 	QString l_sName = l_oDataItem->m_oFlags[l_iIndex];
 
-	for (int i=0; i<m_oGraph->m_oControl->m_oFlagSchemes.size(); ++i)
+	for (int i=0; i<m_oGraph->m_oMediator->m_oFlagSchemes.size(); ++i)
 	{
-		if (m_oGraph->m_oControl->m_oFlagSchemes[i]->m_sId == l_sName)
+		if (m_oGraph->m_oMediator->m_oFlagSchemes[i]->m_sId == l_sName)
 		{
-			QSvgRenderer *l_o = m_oGraph->m_oControl->m_oFlagSchemes[i]->_renderer();
+			QSvgRenderer *l_o = m_oGraph->m_oMediator->m_oFlagSchemes[i]->_renderer();
 			l_o->render(i_oPainter, boundingRect());
 			break;
 		}
