@@ -1,4 +1,4 @@
-/// Thomas Nagy 2007-2009 GPLV3
+/// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef CANVAS_LINK_H
 #define CANVAS_LINK_H
@@ -18,8 +18,7 @@ class canvas_link: public QGraphicsPathItem
 	public:
 		canvas_link(canvas_view *i_oGraphWidget, canvas_item *i_oFrom, canvas_item * i_oTo);
 
-		//enum { Type = gratype(17) };
-		int type() const { return gratype(17); }
+		int type() const { return CANVAS_LINK_T; }
 
 		QColor get_color() {return m_oColor;}
 		void set_color(QColor c) {m_oColor=c;}
@@ -30,14 +29,12 @@ class canvas_link: public QGraphicsPathItem
 
 		bool m_bSel;
 
-	//private:
 		canvas_view *m_oGraph;
 
 		int m_iID;
 		QColor m_oColor;
 		QString m_sLabel;
 
-	//public:
 		void update_pos();
 		void update_spline();
 		void update_triangle();
