@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
@@ -25,6 +25,7 @@ canvas_sort::canvas_sort(canvas_view *i_oGraphWidget, canvas_item *i_oFrom)
 	//m_oColor = QColor("#FFFCD5");
 	//m_oColor = QColor("#ABFBC7");
 
+	hide();
 	QPen l_oPen;
 	l_oPen.setWidth(1);
 	setPen(l_oPen);
@@ -41,9 +42,18 @@ canvas_sort::canvas_sort(canvas_view *i_oGraphWidget, canvas_item *i_oFrom)
 	setParentItem(m_oFrom);
 }
 
-void canvas_sort::paint(QPainter *_painter, const QStyleOptionGraphicsItem *_option, QWidget * i_oW)
+void canvas_sort::paint(QPainter *i_oPainter, const QStyleOptionGraphicsItem *_option, QWidget * i_oW)
 {
-        QGraphicsEllipseItem::paint(_painter, _option, i_oW);
-        _painter->drawText(boundingRect().translated(0, 1), Qt::AlignCenter, m_oFrom->m_sNum);
+	if (m_oGraph->m_iSortCursor + 1 > m_oFrom->m_iNum)
+	{
+		i_oPainter->setBrush(QColor(0, 255, 0));
+	}
+	else
+	{
+		i_oPainter->setBrush(QColor(255, 255, 0));
+	}
+
+	i_oPainter->drawEllipse(boundingRect().adjusted(1, 1, -1, -1));
+        i_oPainter->drawText(boundingRect().translated(0, 1), Qt::AlignCenter, QString::number(m_oFrom->m_iNum));
 }
 
