@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef CANVAS_SORT_H
 #define CANVAS_SORT_H
@@ -17,16 +17,10 @@ class canvas_sort: public QGraphicsEllipseItem
 {
 	public:
 		canvas_sort(canvas_view *i_oGraphWidget, canvas_item *i_oFrom);
-
-		//enum { Type = gratype(19) };
-		int type() const { return gratype(19); }
-	//private:
+		int type() const { return CANVAS_SORT_T; }
 		canvas_view *m_oGraph;
-
-	//public:
 		canvas_item *m_oFrom;
 		void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget *);
-
 };
 
 #endif
