@@ -1,16 +1,16 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef CONFIG_DIALOG_H
 #define CONFIG_DIALOG_H
 
-#include <QDialog>
+#include <KDialog>
 #include <con.h>
 
 class QComboBox;
 class QSpinBox;
 class QTreeWidgetItem;
 class QPushButton;
-class config_dialog : public QDialog
+class config_dialog : public KDialog
 {
 	Q_OBJECT
 	public:
