@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef DATA_VIEW_H
 #define DATA_VIEW_H
@@ -11,12 +11,13 @@ class data_view : public QStackedWidget
 {
 	Q_OBJECT
 	public:
-		data_view(QWidget *i_oParent, data_control *i_oControl);
-		data_control *m_oControl;
+		data_view(QWidget *i_oParent, sem_mediator *i_oControl);
+		sem_mediator *m_oMediator;
 		QLabel *m_oLabel;
 
 	public slots:
-		void synchro_doc(const hash_params&);
+		void notify_select(const QList<int>& unsel, const QList<int>& sel);
+		void notify_datatype(int id);
 };
 
 #endif
