@@ -1,4 +1,7 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
+
+#include <QIcon>
+#include <QSvgRenderer>
 
 #include <QtDebug>
 #	include <QPainter>
