@@ -1,10 +1,12 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef FLAG_SCHEME_H
 #define FLAG_SCHEME_H
 
-#include <QIcon>
-#include <QSvgRenderer>
+//#include <QIcon>
+class QIcon;
+//#include <QSvgRenderer>
+class QSvgRenderer;
 #include <QString>
 #include <con.h>
 
