@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef IMAGE_VIEW_H
 #define IMAGE_VIEW_H
@@ -7,17 +7,19 @@
 #include <QSplitter>
 #include "c\
 on.h"
+#include <KUrl>
 
 class QMenu;
 class image_view : public QWidget
 {
 	Q_OBJECT
 	public:
-		image_view(QWidget*, data_control*);
-		data_control *m_oControl;
+		image_view(QWidget*, sem_mediator*);
+		sem_mediator *m_oMediator;
 		QPixmap m_oPixmap;
 		int m_iId;
 
+		// yes, we could use a QLabel...
 		void paintEvent(QPaintEvent*);
 
 		QMenu *m_oMenu;
@@ -27,7 +29,7 @@ class image_view : public QWidget
 
 		bool event(QEvent*);
 		void mouseReleaseEvent(QMouseEvent*);
-		void do_change_pic(const QString&);
+		void do_change_pic(const KUrl&);
 
 		void dragEnterEvent(QDragEnterEvent*);
 		void dragMoveEvent(QDragMoveEvent*);
@@ -38,10 +40,12 @@ class image_view : public QWidget
 		void sig_message(const QString&, int);
 
 	public slots:
-		void synchro_doc(const hash_params&);
 		void clear_pic();
 		void change_pic();
+		void notify_pic(int id);
 		void context_menu(const QPoint&);
+		void notify_select(const QList<int>& unsel, const QList<int>& sel);
+		void notify_export_item(int id);
 };
 
 #endif
