@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef LINEAR_CONTAINER_H
 #define LINEAR_CONTAINER_H
@@ -8,19 +8,15 @@
 #include "con.h"
 
 class QWidget;
-class data_control;
+class sem_mediator;
 class linear_view;
 class linear_container : public QWidget
 {
-	Q_OBJECT
 	public:
-		linear_container(QWidget *i_oParent, data_control *i_oControl);
+		linear_container(QWidget *i_oParent, sem_mediator *i_oControl);
 
-		data_control *m_oControl;
+		sem_mediator *m_oMediator;
 		linear_view *m_oView;
-
-	public slots:
-		void synchro_doc(const hash_params&);
 };
 
 #endif
