@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef LINEAR_VIEW_H
 #define LINEAR_VIEW_H
@@ -16,8 +16,8 @@ class linear_view : public QTreeWidget
 {
 	Q_OBJECT
 	public:
-		linear_view(QWidget *i_oParent, data_control *i_oControl);
-		data_control *m_oControl;
+		linear_view(QWidget *i_oParent, sem_mediator *i_oControl);
+		sem_mediator *m_oMediator;
 
 		QMap<int, QTreeWidgetItem*> m_oItems;
 
@@ -28,10 +28,17 @@ class linear_view : public QTreeWidget
 		bool m_bLockSelect;
 
 	public slots:
-		void synchro_doc(const hash_params&);
-		//void doubleClickHandler(QTreeWidgetItem*, int);
 		void filter_slot(const QString & i_oS);
 		void selection_changed();
+
+		void notify_add_item(int id);
+		void notify_repaint(int id);
+		void notify_delete_item(int id);
+		void notify_link_items(int id1, int id2);
+		void notify_unlink_items(int id1, int id2);
+		void notify_select(const QList<int>& unsel, const QList<int>& sel);
+		void notify_sort(int id);
+		void notify_edit(int id);
 };
 
 #endif
