@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef PRE_VIEW_H
 #define PRE_VIEW_H
@@ -13,15 +13,14 @@ class pre_view : public QStackedWidget
 {
 	Q_OBJECT
 	public:
-		pre_view(QWidget *i_oParent, data_control *i_oControl);
-		data_control *m_oControl;
+		pre_view(QWidget *i_oParent, sem_mediator *i_oControl);
+		sem_mediator *m_oMediator;
 
 		QLabel *m_oLabel;
 		browser *m_oBrowser;
 
-
 	public slots:
-		void synchro_doc(const hash_params&);
+		void notify_preview();
 };
 
 #endif
