@@ -1,12 +1,14 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef BIND_NODE_H
 #define BIND_NODE_H
 
 #include <QString>
 #include <QList>
+#include <QHash>
 
 class data_item;
+class sem_mediator;
 class bind_node
 {
 	public:
@@ -14,6 +16,10 @@ class bind_node
 
 		static QString get_var(const QString &);
 		static void set_var(const QString &, const QString &);
+		static void set_result(const QString &, const QString &);
+
+		static QString get_item_ids();
+		static bind_node* get_item_by_id(int i);
 
 		// tree manipulation
 		int child_count();
@@ -39,10 +45,15 @@ class bind_node
 
 	//protected:
 
+		static void init(sem_mediator*);
+		static bind_node* create_tree(sem_mediator *model, int i_i);
 		bind_node();
 		~bind_node();
 		static QMap<QString, QString> s_oVars;
+		static QMap<QString, QString> s_oResults;
 		static bind_node* _root;
+		static QHash<int, bind_node*> _cache;
+		static sem_mediator* _model;
 		QList<bind_node*> _children;
 		data_item *m_oItem;
 };
