@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2009 GPLV3
+// Thomas Nagy 2007-2012 GPLV3
 
 #ifndef TEXT_VIEW_H
 #define TEXT_VIEW_H
@@ -9,16 +9,17 @@
 n.h"
 
 #include <QToolBar>
+#include <QList>
+
 class KTextEdit;
 class semantik_win;
 class text_view : public QWidget
 {
 	Q_OBJECT
 	public:
-		text_view(QWidget *i_oParent, data_control *i_oControl);
-		data_control *m_oControl;
+		text_view(QWidget *i_oParent, sem_mediator *i_oControl);
+		sem_mediator *m_oMediator;
 		KTextEdit *m_oEdit;
-		QLineEdit *m_oLineEdit;
 
 		int m_iId;
 
@@ -33,8 +34,6 @@ class text_view : public QWidget
 		QAction *m_oUnderLineAct;
 
 	public slots:
-		void synchro_doc(const hash_params&);
-		void update_summary(const QString &);
 		void update_edit();
 
 		void text_bold();
@@ -42,6 +41,8 @@ class text_view : public QWidget
 		void text_underLine();
 
 		void char_format_changed(const QTextCharFormat&);
+		void notify_select(const QList<int>& unsel, const QList<int>& sel);
+		void notify_text(int id);
 };
 
 #endif
